@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,6 +62,7 @@ import org.osgi.service.event.Event;
 import org.osgi.service.event.EventConstants;
 import org.osgi.service.event.EventHandler;
 import com.openexchange.session.Session;
+import com.openexchange.sessiond.SessiondEventConstants;
 import com.openexchange.sessiond.exception.SessiondException;
 
 /**
@@ -105,7 +106,7 @@ public final class SessiondEventHandler implements EventHandler {
      */
     public ServiceRegistration registerSessiondEventHandler(final BundleContext context) {
         final Hashtable<Object, Object> properties = new Hashtable<Object, Object>();
-        properties.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.TOPICS);
+        properties.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.getAllTopics());
         return context.registerService(EventHandler.class.getName(), this, properties);
 
     }
