@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,8 +66,8 @@ import com.openexchange.caching.objects.CachedSession;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.server.ServiceException;
 import com.openexchange.session.Session;
+import com.openexchange.sessiond.SessiondEventConstants;
 import com.openexchange.sessiond.cache.SessionCache;
-import com.openexchange.sessiond.event.SessiondEventConstants;
 import com.openexchange.sessiond.exception.SessiondException;
 import com.openexchange.sessiond.exception.SessiondException.Code;
 import com.openexchange.sessiond.services.SessiondServiceRegistry;
@@ -94,6 +94,8 @@ public final class SessionHandler {
 
     private static final Log LOG = LogFactory.getLog(SessionHandler.class);
 
+    private static final boolean INFO = LOG.isInfoEnabled();
+
     private static final boolean DEBUG = LOG.isDebugEnabled();
 
     private static ScheduledTimerTask sessiondTimer;
@@ -155,13 +157,24 @@ public final class SessionHandler {
                 }
             }
         }
-        if (LOG.isInfoEnabled()) {
+        if (INFO) {
             LOG.info(new StringBuilder(64).append(propagate ? "Remote" : "Local").append(" removal of user sessions: User=").append(userId).append(
                 ", Context=").append(contextId).toString());
         }
         return retval;
     }
 
+    /**
+     * Gets all sessions associated with given user in specified context
+     * 
+     * @param userId The user ID
+     * @param contextId The context ID
+     * @return The wrapper objects for sessions
+     */
+    public static SessionControl[] getUserSessions(final int userId, final int contextId) {
+        return sessionData.getUserSessions(userId, contextId);
+    }
+
     /**
      * Adds a new session containing given attributes to session container(s)
      * 
@@ -174,7 +187,29 @@ public final class SessionHandler {
      * @return The session ID associated with newly created session
      * @throws SessiondException If creating a new session fails
      */
-    protected static String addSession(final int userId, final String loginName, final String password, final Context context, final String clientHost, final String login) throws SessiondException {
+    protected static String addSession(final int userId, final String loginName, final String password, final Context context, final String clientHost, final String login, String authId) throws SessiondException {
+        checkMaxSessPerUser(userId, context);
+        checkAuthId(login, authId);
+        final String sessionId = sessionIdGenerator.createSessionId(loginName, clientHost);
+        final Session session =
+            new SessionImpl(userId, loginName, password, context.getContextId(), sessionId, sessionIdGenerator.createSecretId(
+                loginName,
+                Long.toString(System.currentTimeMillis())), sessionIdGenerator.createRandomId(), clientHost, login, authId);
+        /*
+         * Add session
+         */
+        sessionData.addSession(session, config.getLifeTime(), noLimit);
+        /*
+         * Post event for created session
+         */
+        postSessionCreation(session);
+        /*
+         * Return session ID
+         */
+        return sessionId;
+    }
+
+    private static void checkMaxSessPerUser(final int userId, final Context context) throws SessiondException {
         final int maxSessPerUser = config.getMaxSessionsPerUser();
         if (maxSessPerUser > 0) {
             final int count = sessionData.getNumOfUserSessions(userId, context);
@@ -182,21 +217,10 @@ public final class SessionHandler {
                 throw new SessiondException(Code.MAX_SESSION_PER_USER_EXCEPTION, null, I(userId), I(context.getContextId()));
             }
         }
+    }
 
-        final String sessionId = sessionIdGenerator.createSessionId(loginName, clientHost);
-        final String secret = sessionIdGenerator.createSecretId(loginName, String.valueOf(System.currentTimeMillis()));
-        final String randomToken = sessionIdGenerator.createRandomId();
-
-        final Session session =
-            new SessionImpl(userId, loginName, password, context.getContextId(), sessionId, secret, randomToken, clientHost, login);
-
-        LOG.info("Session created. ID: " + sessionId + ", Context: " + context.getContextId() + ", User: " + userId);
-
-        sessionData.addSession(session, config.getLifeTime(), noLimit);
-
-        postSessionCreation(session);
-
-        return sessionId;
+    private static void checkAuthId(String login, String authId) throws SessiondException {
+        sessionData.checkAuthId(login, authId);
     }
 
     /**
@@ -225,7 +249,6 @@ public final class SessionHandler {
             return false;
         }
         postSessionRemoval(sessionControl.getSession());
-        LOG.info("Session closed. ID: " + sessionid);
         return true;
     }
 
@@ -297,23 +320,21 @@ public final class SessionHandler {
      * <p>
      * Session is going to be added to local session containers on a cache hit.
      * 
-     * @param secret The secret cookie identifier
+     * @param sessionId The session identifier
      * @param localIP The host's local IP
      * @return A wrapping instance of {@link SessionControl} or <code>null</code>
      */
-    public static SessionControl getCachedSession(final String secret, final String localIP) {
+    public static SessionControl getCachedSession(final String sessionId, final String localIP) {
         if (DEBUG) {
-            LOG.debug(new StringBuilder("getCachedSession <").append(secret).append('>').toString());
+            LOG.debug(new StringBuilder("getCachedSession <").append(sessionId).append('>').toString());
         }
         try {
-            final CachedSession cachedSession = SessionCache.getInstance().removeCachedSession(secret);
+            final CachedSession cachedSession = SessionCache.getInstance().removeCachedSession(sessionId);
             if (null != cachedSession) {
                 if (cachedSession.isMarkedAsRemoved()) {
                     removeUserSessions(cachedSession.getUserId(), cachedSession.getContextId(), false);
                 } else {
-                    /*
-                     * A cache hit! Add to local session containers
-                     */
+                    // A cache hit! Add to local session containers
                     LOG.info("Cached session found. ID: " + cachedSession.getSessionId());
                     return sessionData.addSession(new SessionImpl(cachedSession, localIP), config.getLifeTime(), noLimit);
                 }
@@ -345,7 +366,7 @@ public final class SessionHandler {
             LOG.debug("session cleanup");
         }
         final List<SessionControl> sessionControls = sessionData.rotate();
-        if (LOG.isInfoEnabled()) {
+        if (INFO) {
             for (final SessionControl sessionControl : sessionControls) {
                 LOG.info("Session timed out. ID: " + sessionControl.getSession().getSessionID());
             }
